<?php

namespace Drupal\welcome_username\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Welcome Username Login/Logout' Block.
 *
 * @Block(
 *   id = "welcome_username",
 *   admin_label = @Translation("Welcome Username Login/Logout"),
 *   category = @Translation("Welcome Username Login/Logout"),
 * )
 */
class WelcomeUserNameBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array(
      'welcome_username_welcome_string' => $this->t('Welcome'),
      'welcome_username_logout_string' => $this->t('Logout'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $form['welcome_username_welcome_string'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Welcome String'),
      '#default_value' => $this->configuration['welcome_username_welcome_string'],
    );

    $form['welcome_username_logout_string'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Logout String'),
      '#default_value' => $this->configuration['welcome_username_logout_string'],
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['welcome_username_welcome_string'] = $values['welcome_username_welcome_string'];
    $this->configuration['welcome_username_logout_string'] = $values['welcome_username_logout_string'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    // For anonymous users load a simple login form.
    if (\Drupal::currentUser()->isAnonymous()) {
      $form = \Drupal::formBuilder()->getForm("Drupal\user\Form\UserLoginForm");

      // Placeholders.
      $form['name']['#attributes']['placeholder'] = $form['name']['#description'];
      unset($form['name']['#description']);

      $form['pass']['#attributes']['placeholder'] = $form['pass']['#description'];
      unset($form['pass']['#description']);

      $content['login_form'] = \Drupal::service("renderer")->render($form);
    }

    // For authenticated users show the 'Welcome username' block with a
    // link to the user account and a logout link.
    else {
      $config = $this->getConfiguration();
      // Load user object.
      $user = \Drupal::currentUser();
      $user_name = $user->getDisplayName();

      // Load string from variable table if set.
      $welcome_string = $config['welcome_username_welcome_string'];
      $logout_string = $config['welcome_username_logout_string'];

      // Create a link to the user profile page.
      $content['profile_link'] = \Drupal::l(t($welcome_string) . " " . $user_name, \Drupal\Core\Url::fromRoute('user.page'));

      // Create a logout link.
      $content['logout_link'] = \Drupal::l(t($logout_string), \Drupal\Core\Url::fromRoute('user.logout'));

    }

    return [
      '#theme' => 'welcome_username_login',
      '#content' => $content,
    ];
  }

}
